import { Pool } from 'pg';
import { config } from '../config';

// 创建连接池
const pool = new Pool({
  user: config.db.user,
  host: config.db.host,
  database: config.db.database,
  password: config.db.password,
  port: config.db.port,
});

// 导出查询函数
export const query = async (text: string, params?: any[]) => {
  try {
    return await pool.query(text, params);
  } catch (error) {
    const err = error as Error;
    throw new Error(`Database query failed: ${err.message}`);
  }
};

// 测试数据库连接
export const testDbConnection = async () => {
  try {
    const result = await query('SELECT NOW()');
    return { time: result.rows[0].now };
  } catch (error) {
    const err = error as Error;
    throw new Error(`Database connection failed: ${err.message}`);
  }
};

// 添加通用错误处理
pool.on('error', (err: Error) => {
  console.error('Unexpected database error', err);
});

// 初始化数据库 - 检查并创建 cloth 表
export const initializeDatabase = async () => {
  try {
    // 检查 cloth 表是否存在
    const tableExists = await query(
      `SELECT EXISTS (
        SELECT FROM information_schema.tables 
        WHERE table_schema = 'public' 
        AND table_name = 'cloth'
      )`
    );
    
    if (!tableExists.rows[0].exists) {
      console.log('Creating cloth table...');
      await query(`
        CREATE TABLE cloth (
          id SERIAL PRIMARY KEY,
          name VARCHAR(100) NOT NULL,
          description TEXT,
          price DECIMAL(10,2) NOT NULL,
          size VARCHAR(10)[],
          colors VARCHAR(20)[],
          material VARCHAR(50),
          created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
          updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
        )
      `);
      console.log('Cloth table created successfully');
    } else {
      console.log('Cloth table already exists');
    }
    
    // 测试数据库连接
    const dbStatus = await testDbConnection();
    console.log('Database connection successful:', dbStatus);
    
  } catch (error) {
    const err = error as Error;
    console.error('Database initialization failed:', err.message);
    throw err;
  }
};